==> kubernetes-model-apiextensions-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionSpecFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface CustomResourceDefinitionSpecFluent<A extends CustomResourceDefinitionSpecFluent<A>> extends Fluent<A>{
  public A addToAdditionalPrinterColumns(Integer index,CustomResourceColumnDefinition item);
  public A setToAdditionalPrinterColumns(Integer index,CustomResourceColumnDefinition item);
  public A addToAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition... items);
  public A addAllToAdditionalPrinterColumns(Collection<CustomResourceColumnDefinition> items);
  public A removeFromAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition... items);
  public A removeAllFromAdditionalPrinterColumns(Collection<CustomResourceColumnDefinition> items);
  public A removeMatchingFromAdditionalPrinterColumns(Predicate<CustomResourceColumnDefinitionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAdditionalPrinterColumns instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CustomResourceColumnDefinition> getAdditionalPrinterColumns();
  public List<CustomResourceColumnDefinition> buildAdditionalPrinterColumns();
  public CustomResourceColumnDefinition buildAdditionalPrinterColumn(Integer index);
  public CustomResourceColumnDefinition buildFirstAdditionalPrinterColumn();
  public CustomResourceColumnDefinition buildLastAdditionalPrinterColumn();
  public CustomResourceColumnDefinition buildMatchingAdditionalPrinterColumn(Predicate<CustomResourceColumnDefinitionBuilder> predicate);
  public Boolean hasMatchingAdditionalPrinterColumn(Predicate<CustomResourceColumnDefinitionBuilder> predicate);
  public A withAdditionalPrinterColumns(List<CustomResourceColumnDefinition> additionalPrinterColumns);
  public A withAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition... additionalPrinterColumns);
  public Boolean hasAdditionalPrinterColumns();
  public CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumn();
  public CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumnLike(CustomResourceColumnDefinition item);
  public CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> setNewAdditionalPrinterColumnLike(Integer index,CustomResourceColumnDefinition item);
  public CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editAdditionalPrinterColumn(Integer index);
  public CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editFirstAdditionalPrinterColumn();
  public CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editLastAdditionalPrinterColumn();
  public CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editMatchingAdditionalPrinterColumn(Predicate<CustomResourceColumnDefinitionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConversion instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomResourceConversion getConversion();
  public CustomResourceConversion buildConversion();
  public A withConversion(CustomResourceConversion conversion);
  public Boolean hasConversion();
  public CustomResourceDefinitionSpecFluent.ConversionNested<A> withNewConversion();
  public CustomResourceDefinitionSpecFluent.ConversionNested<A> withNewConversionLike(CustomResourceConversion item);
  public CustomResourceDefinitionSpecFluent.ConversionNested<A> editConversion();
  public CustomResourceDefinitionSpecFluent.ConversionNested<A> editOrNewConversion();
  public CustomResourceDefinitionSpecFluent.ConversionNested<A> editOrNewConversionLike(CustomResourceConversion item);
  public String getGroup();
  public A withGroup(String group);
  public Boolean hasGroup();
  
  /**
   * This method has been deprecated, please use method buildNames instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomResourceDefinitionNames getNames();
  public CustomResourceDefinitionNames buildNames();
  public A withNames(CustomResourceDefinitionNames names);
  public Boolean hasNames();
  public CustomResourceDefinitionSpecFluent.NamesNested<A> withNewNames();
  public CustomResourceDefinitionSpecFluent.NamesNested<A> withNewNamesLike(CustomResourceDefinitionNames item);
  public CustomResourceDefinitionSpecFluent.NamesNested<A> editNames();
  public CustomResourceDefinitionSpecFluent.NamesNested<A> editOrNewNames();
  public CustomResourceDefinitionSpecFluent.NamesNested<A> editOrNewNamesLike(CustomResourceDefinitionNames item);
  public Boolean getPreserveUnknownFields();
  public A withPreserveUnknownFields(Boolean preserveUnknownFields);
  public Boolean hasPreserveUnknownFields();
  public String getScope();
  public A withScope(String scope);
  public Boolean hasScope();
  
  /**
   * This method has been deprecated, please use method buildSubresources instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomResourceSubresources getSubresources();
  public CustomResourceSubresources buildSubresources();
  public A withSubresources(CustomResourceSubresources subresources);
  public Boolean hasSubresources();
  public CustomResourceDefinitionSpecFluent.SubresourcesNested<A> withNewSubresources();
  public CustomResourceDefinitionSpecFluent.SubresourcesNested<A> withNewSubresourcesLike(CustomResourceSubresources item);
  public CustomResourceDefinitionSpecFluent.SubresourcesNested<A> editSubresources();
  public CustomResourceDefinitionSpecFluent.SubresourcesNested<A> editOrNewSubresources();
  public CustomResourceDefinitionSpecFluent.SubresourcesNested<A> editOrNewSubresourcesLike(CustomResourceSubresources item);
  
  /**
   * This method has been deprecated, please use method buildValidation instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomResourceValidation getValidation();
  public CustomResourceValidation buildValidation();
  public A withValidation(CustomResourceValidation validation);
  public Boolean hasValidation();
  public CustomResourceDefinitionSpecFluent.ValidationNested<A> withNewValidation();
  public CustomResourceDefinitionSpecFluent.ValidationNested<A> withNewValidationLike(CustomResourceValidation item);
  public CustomResourceDefinitionSpecFluent.ValidationNested<A> editValidation();
  public CustomResourceDefinitionSpecFluent.ValidationNested<A> editOrNewValidation();
  public CustomResourceDefinitionSpecFluent.ValidationNested<A> editOrNewValidationLike(CustomResourceValidation item);
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public A addToVersions(Integer index,CustomResourceDefinitionVersion item);
  public A setToVersions(Integer index,CustomResourceDefinitionVersion item);
  public A addToVersions(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion... items);
  public A addAllToVersions(Collection<CustomResourceDefinitionVersion> items);
  public A removeFromVersions(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion... items);
  public A removeAllFromVersions(Collection<CustomResourceDefinitionVersion> items);
  public A removeMatchingFromVersions(Predicate<CustomResourceDefinitionVersionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildVersions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CustomResourceDefinitionVersion> getVersions();
  public List<CustomResourceDefinitionVersion> buildVersions();
  public CustomResourceDefinitionVersion buildVersion(Integer index);
  public CustomResourceDefinitionVersion buildFirstVersion();
  public CustomResourceDefinitionVersion buildLastVersion();
  public CustomResourceDefinitionVersion buildMatchingVersion(Predicate<CustomResourceDefinitionVersionBuilder> predicate);
  public Boolean hasMatchingVersion(Predicate<CustomResourceDefinitionVersionBuilder> predicate);
  public A withVersions(List<CustomResourceDefinitionVersion> versions);
  public A withVersions(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion... versions);
  public Boolean hasVersions();
  public CustomResourceDefinitionSpecFluent.VersionsNested<A> addNewVersion();
  public CustomResourceDefinitionSpecFluent.VersionsNested<A> addNewVersionLike(CustomResourceDefinitionVersion item);
  public CustomResourceDefinitionSpecFluent.VersionsNested<A> setNewVersionLike(Integer index,CustomResourceDefinitionVersion item);
  public CustomResourceDefinitionSpecFluent.VersionsNested<A> editVersion(Integer index);
  public CustomResourceDefinitionSpecFluent.VersionsNested<A> editFirstVersion();
  public CustomResourceDefinitionSpecFluent.VersionsNested<A> editLastVersion();
  public CustomResourceDefinitionSpecFluent.VersionsNested<A> editMatchingVersion(Predicate<CustomResourceDefinitionVersionBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withPreserveUnknownFields();
  public interface AdditionalPrinterColumnsNested<N> extends Nested<N>,CustomResourceColumnDefinitionFluent<CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<N>>{
    public N and();
    public N endAdditionalPrinterColumn();
    
  }
  public interface ConversionNested<N> extends Nested<N>,CustomResourceConversionFluent<CustomResourceDefinitionSpecFluent.ConversionNested<N>>{
    public N and();
    public N endConversion();
    
  }
  public interface NamesNested<N> extends Nested<N>,CustomResourceDefinitionNamesFluent<CustomResourceDefinitionSpecFluent.NamesNested<N>>{
    public N and();
    public N endNames();
    
  }
  public interface SubresourcesNested<N> extends Nested<N>,CustomResourceSubresourcesFluent<CustomResourceDefinitionSpecFluent.SubresourcesNested<N>>{
    public N and();
    public N endSubresources();
    
  }
  public interface ValidationNested<N> extends Nested<N>,CustomResourceValidationFluent<CustomResourceDefinitionSpecFluent.ValidationNested<N>>{
    public N and();
    public N endValidation();
    
  }
  public interface VersionsNested<N> extends Nested<N>,CustomResourceDefinitionVersionFluent<CustomResourceDefinitionSpecFluent.VersionsNested<N>>{
    public N and();
    public N endVersion();
    
  }
  
}

==> kubernetes-model-apiextensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionSpecFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface CustomResourceDefinitionSpecFluent<A extends CustomResourceDefinitionSpecFluent<A>> extends Fluent<A>{
  public A addToAdditionalPrinterColumns(int index,CustomResourceColumnDefinition item);
  public A setToAdditionalPrinterColumns(int index,CustomResourceColumnDefinition item);
  public A addToAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition... items);
  public A addAllToAdditionalPrinterColumns(Collection<CustomResourceColumnDefinition> items);
  public A removeFromAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition... items);
  public A removeAllFromAdditionalPrinterColumns(Collection<CustomResourceColumnDefinition> items);
  public A removeMatchingFromAdditionalPrinterColumns(Predicate<CustomResourceColumnDefinitionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildAdditionalPrinterColumns instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CustomResourceColumnDefinition> getAdditionalPrinterColumns();
  public List<CustomResourceColumnDefinition> buildAdditionalPrinterColumns();
  public CustomResourceColumnDefinition buildAdditionalPrinterColumn(int index);
  public CustomResourceColumnDefinition buildFirstAdditionalPrinterColumn();
  public CustomResourceColumnDefinition buildLastAdditionalPrinterColumn();
  public CustomResourceColumnDefinition buildMatchingAdditionalPrinterColumn(Predicate<CustomResourceColumnDefinitionBuilder> predicate);
  public Boolean hasMatchingAdditionalPrinterColumn(Predicate<CustomResourceColumnDefinitionBuilder> predicate);
  public A withAdditionalPrinterColumns(List<CustomResourceColumnDefinition> additionalPrinterColumns);
  public A withAdditionalPrinterColumns(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceColumnDefinition... additionalPrinterColumns);
  public Boolean hasAdditionalPrinterColumns();
  public CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumn();
  public CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> addNewAdditionalPrinterColumnLike(CustomResourceColumnDefinition item);
  public CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> setNewAdditionalPrinterColumnLike(int index,CustomResourceColumnDefinition item);
  public CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editAdditionalPrinterColumn(int index);
  public CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editFirstAdditionalPrinterColumn();
  public CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editLastAdditionalPrinterColumn();
  public CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<A> editMatchingAdditionalPrinterColumn(Predicate<CustomResourceColumnDefinitionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConversion instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomResourceConversion getConversion();
  public CustomResourceConversion buildConversion();
  public A withConversion(CustomResourceConversion conversion);
  public Boolean hasConversion();
  public CustomResourceDefinitionSpecFluent.ConversionNested<A> withNewConversion();
  public CustomResourceDefinitionSpecFluent.ConversionNested<A> withNewConversionLike(CustomResourceConversion item);
  public CustomResourceDefinitionSpecFluent.ConversionNested<A> editConversion();
  public CustomResourceDefinitionSpecFluent.ConversionNested<A> editOrNewConversion();
  public CustomResourceDefinitionSpecFluent.ConversionNested<A> editOrNewConversionLike(CustomResourceConversion item);
  public String getGroup();
  public A withGroup(String group);
  public Boolean hasGroup();
  
  /**
   * This method has been deprecated, please use method buildNames instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomResourceDefinitionNames getNames();
  public CustomResourceDefinitionNames buildNames();
  public A withNames(CustomResourceDefinitionNames names);
  public Boolean hasNames();
  public CustomResourceDefinitionSpecFluent.NamesNested<A> withNewNames();
  public CustomResourceDefinitionSpecFluent.NamesNested<A> withNewNamesLike(CustomResourceDefinitionNames item);
  public CustomResourceDefinitionSpecFluent.NamesNested<A> editNames();
  public CustomResourceDefinitionSpecFluent.NamesNested<A> editOrNewNames();
  public CustomResourceDefinitionSpecFluent.NamesNested<A> editOrNewNamesLike(CustomResourceDefinitionNames item);
  public Boolean getPreserveUnknownFields();
  public A withPreserveUnknownFields(Boolean preserveUnknownFields);
  public Boolean hasPreserveUnknownFields();
  public String getScope();
  public A withScope(String scope);
  public Boolean hasScope();
  
  /**
   * This method has been deprecated, please use method buildSubresources instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomResourceSubresources getSubresources();
  public CustomResourceSubresources buildSubresources();
  public A withSubresources(CustomResourceSubresources subresources);
  public Boolean hasSubresources();
  public CustomResourceDefinitionSpecFluent.SubresourcesNested<A> withNewSubresources();
  public CustomResourceDefinitionSpecFluent.SubresourcesNested<A> withNewSubresourcesLike(CustomResourceSubresources item);
  public CustomResourceDefinitionSpecFluent.SubresourcesNested<A> editSubresources();
  public CustomResourceDefinitionSpecFluent.SubresourcesNested<A> editOrNewSubresources();
  public CustomResourceDefinitionSpecFluent.SubresourcesNested<A> editOrNewSubresourcesLike(CustomResourceSubresources item);
  
  /**
   * This method has been deprecated, please use method buildValidation instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomResourceValidation getValidation();
  public CustomResourceValidation buildValidation();
  public A withValidation(CustomResourceValidation validation);
  public Boolean hasValidation();
  public CustomResourceDefinitionSpecFluent.ValidationNested<A> withNewValidation();
  public CustomResourceDefinitionSpecFluent.ValidationNested<A> withNewValidationLike(CustomResourceValidation item);
  public CustomResourceDefinitionSpecFluent.ValidationNested<A> editValidation();
  public CustomResourceDefinitionSpecFluent.ValidationNested<A> editOrNewValidation();
  public CustomResourceDefinitionSpecFluent.ValidationNested<A> editOrNewValidationLike(CustomResourceValidation item);
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public A addToVersions(int index,CustomResourceDefinitionVersion item);
  public A setToVersions(int index,CustomResourceDefinitionVersion item);
  public A addToVersions(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion... items);
  public A addAllToVersions(Collection<CustomResourceDefinitionVersion> items);
  public A removeFromVersions(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion... items);
  public A removeAllFromVersions(Collection<CustomResourceDefinitionVersion> items);
  public A removeMatchingFromVersions(Predicate<CustomResourceDefinitionVersionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildVersions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<CustomResourceDefinitionVersion> getVersions();
  public List<CustomResourceDefinitionVersion> buildVersions();
  public CustomResourceDefinitionVersion buildVersion(int index);
  public CustomResourceDefinitionVersion buildFirstVersion();
  public CustomResourceDefinitionVersion buildLastVersion();
  public CustomResourceDefinitionVersion buildMatchingVersion(Predicate<CustomResourceDefinitionVersionBuilder> predicate);
  public Boolean hasMatchingVersion(Predicate<CustomResourceDefinitionVersionBuilder> predicate);
  public A withVersions(List<CustomResourceDefinitionVersion> versions);
  public A withVersions(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionVersion... versions);
  public Boolean hasVersions();
  public CustomResourceDefinitionSpecFluent.VersionsNested<A> addNewVersion();
  public CustomResourceDefinitionSpecFluent.VersionsNested<A> addNewVersionLike(CustomResourceDefinitionVersion item);
  public CustomResourceDefinitionSpecFluent.VersionsNested<A> setNewVersionLike(int index,CustomResourceDefinitionVersion item);
  public CustomResourceDefinitionSpecFluent.VersionsNested<A> editVersion(int index);
  public CustomResourceDefinitionSpecFluent.VersionsNested<A> editFirstVersion();
  public CustomResourceDefinitionSpecFluent.VersionsNested<A> editLastVersion();
  public CustomResourceDefinitionSpecFluent.VersionsNested<A> editMatchingVersion(Predicate<CustomResourceDefinitionVersionBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withPreserveUnknownFields();
  public interface AdditionalPrinterColumnsNested<N> extends Nested<N>,CustomResourceColumnDefinitionFluent<CustomResourceDefinitionSpecFluent.AdditionalPrinterColumnsNested<N>>{
    public N and();
    public N endAdditionalPrinterColumn();
    
  }
  public interface ConversionNested<N> extends Nested<N>,CustomResourceConversionFluent<CustomResourceDefinitionSpecFluent.ConversionNested<N>>{
    public N and();
    public N endConversion();
    
  }
  public interface NamesNested<N> extends Nested<N>,CustomResourceDefinitionNamesFluent<CustomResourceDefinitionSpecFluent.NamesNested<N>>{
    public N and();
    public N endNames();
    
  }
  public interface SubresourcesNested<N> extends Nested<N>,CustomResourceSubresourcesFluent<CustomResourceDefinitionSpecFluent.SubresourcesNested<N>>{
    public N and();
    public N endSubresources();
    
  }
  public interface ValidationNested<N> extends Nested<N>,CustomResourceValidationFluent<CustomResourceDefinitionSpecFluent.ValidationNested<N>>{
    public N and();
    public N endValidation();
    
  }
  public interface VersionsNested<N> extends Nested<N>,CustomResourceDefinitionVersionFluent<CustomResourceDefinitionSpecFluent.VersionsNested<N>>{
    public N and();
    public N endVersion();
    
  }
  
}
